Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6293)

Unified Diff: chrome/common/safe_browsing/csd.proto

Issue 2029903002: Add token field to ClientSafeBrowsingReportReqeust (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: nit in test Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/safe_browsing/csd.proto
diff --git a/chrome/common/safe_browsing/csd.proto b/chrome/common/safe_browsing/csd.proto
index 1f0f3044930c03d838bd2b063fbca081197fa201..66e14f449d655c89b336c103926f5474ddf282ae 100644
--- a/chrome/common/safe_browsing/csd.proto
+++ b/chrome/common/safe_browsing/csd.proto
@@ -694,7 +694,7 @@ message DownloadMetadata {
// A Detailed Safebrowsing Report from clients. Chrome safebrowsing reports are
// only sent by Chrome users who have opted into extended Safe Browsing.
// This proto is replacing ClientMalwareReportRequest.
-// Next tag: 12
+// Next tag: 16
message ClientSafeBrowsingReportRequest {
// Note: A lot of the "optional" fields would make sense to be
// "required" instead. However, having them as optional allows the
@@ -710,6 +710,7 @@ message ClientSafeBrowsingReportRequest {
CLIENT_SIDE_MALWARE_URL = 5;
DANGEROUS_DOWNLOAD_RECOVERY = 6;
DANGEROUS_DOWNLOAD_WARNING = 7;
+ DANGEROUS_DOWNLOAD_BY_API = 10;
}
message HTTPHeader {
@@ -761,8 +762,8 @@ message ClientSafeBrowsingReportRequest {
optional ReportType type = 10;
// Only set if ReportType is DANGEROUS_DOWNLOAD_RECOVERY or
// DANGEROUS_DOWNLOAD_WARNING.
optional ClientDownloadResponse.Verdict download_verdict = 11;
// URL of the page in the address bar.
@@ -785,4 +786,9 @@ message ClientSafeBrowsingReportRequest {
// Whether user visited this origin before.
optional bool repeat_visit = 9;
+
+ // The same token in ClientDownloadResponse. This field is only set if its
+ // report type is DANGEROUS_DOWNLOAD_RECOVERY, DANGEROUS_DOWNLOAD_WARNING or
+ // DANGEROUS_DOWNLOAD_BY_API.
+ optional bytes token = 15;
}

Powered by Google App Engine
@@ -761,8 +762,8 @@ message ClientSafeBrowsingReportRequest {
optional ReportType type = 10;
- // Only set if ReportType is DANGEROUS_DOWNLOAD_RECOVERY or
- // DANGEROUS_DOWNLOAD_WARNING.
+ // Only set if ReportType is DANGEROUS_DOWNLOAD_RECOVERY,
+ // DANGEROUS_DOWNLOAD_WARNING or DANGEROUS_DOWNLOAD_BY_API.
optional ClientDownloadResponse.Verdict download_verdict = 11;
// URL of the page in the address bar.
This is Rietveld 408576698